==> plugin.audio.cro-1.1.7.zip: plugin.audio.cro-leia/README.md <==
<h1>Český rozhlas</h1>
<p>
Kodi doplněk Český rozhlas (ČRo) upožnuje poslech pořadů archivu stanic Českého rozhlasu 
<p>
<br>
v1.1.7 (2020-11-27)<br>
- přidání závislosti na verzi pythonu (oddělení větví pro Matrix a Leia a starší)<br><br>

v1.1.6 (2020-10-11)<br>
- ošetření chybějícího adresáře pro data doplňku<br><br>

v1.1.4 (2020-10-10)<br>    
- komatibilita s Kodi 19 (Matrix)<br>
- oprava přehrávání některých epizod v tématech<br><br>

v1.1.2/3 (2020-09-30)<br>
- přidaná možnost nastavení počtu pořadů nebo epizod na stránku (default 20)<br><br>

v1.1.1 (2020-09-28)<br>
- přejmenování loga doplňku<br>
- zrychlení spuštění přehrávání u živého vysílání<br><br>

v1.1.0 (2020-09-27)<br>
- nové logo (díky delfin-chikago) a ikony<br><br>

v1.0.9 (2020-09-13)<br>
- oprava přehrávání živého vysílání u stanic bez ikony<br><br>

v1.0.8 (2020-09-12)<br>
- opravené přehrávání ve widgetech témat<br>
- živé vysílání se spouští přes playlist (zůstává otevřený seznam stanic)<br><br>

v1.0.7 (2020-09-11)<br>
- přesun položek z oblíbených pořadů do hlavního menu<br>
- doplnění možnosti přidat pořad rovnou do ostatních oblíbených<br><br>

v1.0.6 (2020-09-11)<br>
- oprava odstraňování pořadů z oblíbených<br><br>

v1.0.5 (2020-09-11)<br>
- přidány ostatní oblíbené pořady (nesledují se nové epizody), přesouvat lze přes kontextové menu<br>
- přesun novinek v oblíbených pořadech do Oblíbených pořadů<br>
- oprava označování nových epizod u stránkování, aktualizace označení po přehrání<br><br>

v1.0.4 (2020-09-10)<br>
- úprava jména položky na přidání do oblíbených pořadů v kontextovém menu<br>
- oprava popisu v záhlaví v nabídce Pořady<br>
- přidány novinek v oblíbených pořadech<br><br>

v1.0.3 (2020-09-08)<br>
- přidány údaje o obsazení pořadů<br>
- u témat přidané dynamické nabídky pořadů<br>
- přidané mazání vyhledávaných řetězců<br>
- úprava titulu v metadatech epizod aby se korektně zobrazoval v seznamu stop, přidání data vysílání<br>
- přidání oblíbených pořadů<br>
- oprava vyhledávání<br>
- přidání stránkování u zobrazení epizod pořadu, u stránkování odstraněná položka předchozí stránka<br><br>

v1.0.2 (2020-09-07)<br>
- přidání informace o dílech, pokud jsou k dispozici<br><br>

v1.0.1 (2020-09-07)<br>
- změna vyhledávání z fulltextového na hledání v názvu epizody/pořadu<br>
- stránkování v pořadech<br>
- oštření chyby kdy u pořadu chyběla stanice<br><br>

v1.0.0 (2020-09-06)<br>
- první vydání<br><br>

==> plugin.audio.cro-1.2.1.zip: plugin.audio.cro-leia/README.md <==
<h1>Český rozhlas</h1>
<p>
Kodi doplněk Český rozhlas (ČRo) upožnuje poslech pořadů archivu stanic Českého rozhlasu 
<p>
<br>
v1.2.1 (2021-12-03)<br>
- do nastavení přidané nastavení preference formátu AAC před MP3<br>
- přidaná možnost přehrávat AAC streamy<br><br>

v1.2.0 (2021-12-03)<br>
- oprava logování v Kodi 19<br>
- ošetření stanic bez mp3 streamu<br><br>

v1.1.9 (2021-08-21)<br>
- ošetření neexistujících pořadů v oblíbených<br><br>

v1.1.8 (2021-04-10)<br>
- úprava spouštění přehrávání v Kodi 19<br><br>

v1.1.7 (2020-11-27)<br>
- přidání závislosti na verzi pythonu (oddělení větví pro Matrix a Leia a starší)<br><br>

v1.1.6 (2020-10-11)<br>
- ošetření chybějícího adresáře pro data doplňku<br><br>

v1.1.4 (2020-10-10)<br>    
- komatibilita s Kodi 19 (Matrix)<br>
- oprava přehrávání některých epizod v tématech<br><br>

v1.1.2/3 (2020-09-30)<br>
- přidaná možnost nastavení počtu pořadů nebo epizod na stránku (default 20)<br><br>

v1.1.1 (2020-09-28)<br>
- přejmenování loga doplňku<br>
- zrychlení spuštění přehrávání u živého vysílání<br><br>

v1.1.0 (2020-09-27)<br>
- nové logo (díky delfin-chikago) a ikony<br><br>

v1.0.9 (2020-09-13)<br>
- oprava přehrávání živého vysílání u stanic bez ikony<br><br>

v1.0.8 (2020-09-12)<br>
- opravené přehrávání ve widgetech témat<br>
- živé vysílání se spouští přes playlist (zůstává otevřený seznam stanic)<br><br>

v1.0.7 (2020-09-11)<br>
- přesun položek z oblíbených pořadů do hlavního menu<br>
- doplnění možnosti přidat pořad rovnou do ostatních oblíbených<br><br>

v1.0.6 (2020-09-11)<br>
- oprava odstraňování pořadů z oblíbených<br><br>

v1.0.5 (2020-09-11)<br>
- přidány ostatní oblíbené pořady (nesledují se nové epizody), přesouvat lze přes kontextové menu<br>
- přesun novinek v oblíbených pořadech do Oblíbených pořadů<br>
- oprava označování nových epizod u stránkování, aktualizace označení po přehrání<br><br>

v1.0.4 (2020-09-10)<br>
- úprava jména položky na přidání do oblíbených pořadů v kontextovém menu<br>
- oprava popisu v záhlaví v nabídce Pořady<br>
- přidány novinek v oblíbených pořadech<br><br>

v1.0.3 (2020-09-08)<br>
- přidány údaje o obsazení pořadů<br>
- u témat přidané dynamické nabídky pořadů<br>
- přidané mazání vyhledávaných řetězců<br>
- úprava titulu v metadatech epizod aby se korektně zobrazoval v seznamu stop, přidání data vysílání<br>
- přidání oblíbených pořadů<br>
- oprava vyhledávání<br>
- přidání stránkování u zobrazení epizod pořadu, u stránkování odstraněná položka předchozí stránka<br><br>

v1.0.2 (2020-09-07)<br>
- přidání informace o dílech, pokud jsou k dispozici<br><br>

v1.0.1 (2020-09-07)<br>
- změna vyhledávání z fulltextového na hledání v názvu epizody/pořadu<br>
- stránkování v pořadech<br>
- oštření chyby kdy u pořadu chyběla stanice<br><br>

v1.0.0 (2020-09-06)<br>
- první vydání<br><br>
